pub struct FlashCmpa { /* private fields */ }Expand description
FLASH_CMPA
Implementations
Sourceimpl FlashCmpa
impl FlashCmpa
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn spi_flash_cfg(self) -> Reg<SpiFlashCfg, RW>
pub const fn spi_flash_cfg(self) -> Reg<SpiFlashCfg, RW>
no description available
Sourcepub const fn cc_socu_pin(self) -> Reg<CcSocuPin, RW>
pub const fn cc_socu_pin(self) -> Reg<CcSocuPin, RW>
no description available
Sourcepub const fn cc_socu_dflt(self) -> Reg<CcSocuDflt, RW>
pub const fn cc_socu_dflt(self) -> Reg<CcSocuDflt, RW>
no description available
Sourcepub const fn vendor_usage(self) -> Reg<VendorUsage, RW>
pub const fn vendor_usage(self) -> Reg<VendorUsage, RW>
no description available
Sourcepub const fn secure_boot_cfg(self) -> Reg<SecureBootCfg, RW>
pub const fn secure_boot_cfg(self) -> Reg<SecureBootCfg, RW>
Secure boot configuration flags.
Sourcepub const fn prince_base_addr(self) -> Reg<PrinceBaseAddr, RW>
pub const fn prince_base_addr(self) -> Reg<PrinceBaseAddr, RW>
no description available
Sourcepub const fn prince_sr_0(self) -> Reg<PrinceSr0, RW>
pub const fn prince_sr_0(self) -> Reg<PrinceSr0, RW>
Region 0, sub-region enable
Sourcepub const fn prince_sr_1(self) -> Reg<PrinceSr1, RW>
pub const fn prince_sr_1(self) -> Reg<PrinceSr1, RW>
Region 1, sub-region enable
Sourcepub const fn prince_sr_2(self) -> Reg<PrinceSr2, RW>
pub const fn prince_sr_2(self) -> Reg<PrinceSr2, RW>
Region 2, sub-region enable
Sourcepub const fn xtal_32khz_capabank_trim(self) -> Reg<Xtal32khzCapabankTrim, RW>
pub const fn xtal_32khz_capabank_trim(self) -> Reg<Xtal32khzCapabankTrim, RW>
Xtal 32kHz capabank triming.
Sourcepub const fn xtal_16mhz_capabank_trim(self) -> Reg<Xtal16mhzCapabankTrim, RW>
pub const fn xtal_16mhz_capabank_trim(self) -> Reg<Xtal16mhzCapabankTrim, RW>
Xtal 16MHz capabank triming.
Sourcepub const fn flash_remap_size(self) -> Reg<FlashRemapSize, RW>
pub const fn flash_remap_size(self) -> Reg<FlashRemapSize, RW>
This 32-bit register contains the size of the image to remap, in bytes. The 12 LSBs are ignored, so the size granularity is 4KB.
Sourcepub const fn flash_remap_offset(self) -> Reg<FlashRemapOffset, RW>
pub const fn flash_remap_offset(self) -> Reg<FlashRemapOffset, RW>
This 32-bit register contains the offset by which the image is to be remapped. The 12 LSBs are ignored, so the remap granularity is 4KB.
Sourcepub const fn rotkh(self, n: usize) -> Reg<Rotkh, RW>
pub const fn rotkh(self, n: usize) -> Reg<Rotkh, RW>
ROTKHindex for Root of Trust Keys Table hash[(((7 - index) * 32) + 31):((7 - index) * 32)]
Sourcepub const fn customer_defined(self, n: usize) -> Reg<CustomerDefined, RW>
pub const fn customer_defined(self, n: usize) -> Reg<CustomerDefined, RW>
Customer Defined (Programable through ROM API)
Sourcepub const fn sha256_digest(self, n: usize) -> Reg<Sha256Digest, RW>
pub const fn sha256_digest(self, n: usize) -> Reg<Sha256Digest, RW>
SHA256_DIGESTindex for DIGEST[((index * 32) + 31):(index * 32)]